@@ -8,9 +8,9 @@ use Log::ger;
 use Perinci::Object 'envresmulti';
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-10-10'; # DATE
+our $DATE = '2022-10-21'; # DATE
 our $DIST = 'App-GoogleSearchUtils'; # DIST
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 our %SPEC;
 
@@ -28,9 +28,12 @@ sub _fmt_org_link {
 
 $SPEC{google_search} = {
     v => 1.1,
-    summary => 'Open google search page in browser',
+    summary => '(DEPRECATED) Open google search page in browser',
     description => <<'_',
 
+*DEPRECATION NOTICE*: Deprecated in favor of <prog:web-search> from
+<pm:App::WebSearchUtils>.
+
 This utility can save you time when you want to open multiple queries (with
 added common prefix/suffix words) or specify some options like time limit. It
 will formulate the search URL(s) then open them for you in browser. You can also
@@ -439,7 +442,7 @@ App::GoogleSearchUtils - CLI utilites related to google searching
 
 =head1 VERSION
 
-This document describes version 0.014 of App::GoogleSearchUtils (from Perl distribution App-GoogleSearchUtils), released on 2022-10-10.
+This document describes version 0.015 of App::GoogleSearchUtils (from Perl distribution App-GoogleSearchUtils), released on 2022-10-21.
 
 =head1 SYNOPSIS
 
@@ -460,7 +463,10 @@ Usage:
 
  google_search(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
-Open google search page in browser.
+(DEPRECATED) Open google search page in browser.
+
+I<DEPRECATION NOTICE>: Deprecated in favor of L<web-search> from
+L<App::WebSearchUtils>.
 
 This utility can save you time when you want to open multiple queries (with
 added common prefix/suffix words) or specify some options like time limit. It
@@ -538,18 +544,24 @@ String to add at the beginning of each query.
 
 =item * B<queries> => I<array[str]>
 
+(No description)
+
 =item * B<queries_from> => I<filename>
 
 Supply queries from lines of text file (specify "-" for stdin).
 
 =item * B<time_end> => I<date>
 
+(No description)
+
 =item * B<time_past> => I<str>
 
 Limit time period to the past hourE<sol>24hourE<sol>weekE<sol>monthE<sol>year.
 
 =item * B<time_start> => I<date>
 
+(No description)
+
 =item * B<type> => I<str> (default: "web")
 
 Search type.
